@@ -9,7 +9,8 @@ knitr::opts_chunk$set(
 
 ## ----packages---------------------------------------------------------------------------------------------------------------------------------------
 library(rsimsum)
-library(tidyverse)
+library(dplyr)
+library(ggplot2)
 library(knitr)
 
 ## ----table------------------------------------------------------------------------------------------------------------------------------------------
