@@ -3,17 +3,17 @@ context("summary.multisimsum")
 test_that("summarising a simsum object works fine and prints ok", {
   data("frailty")
   x <- multisimsum(data = frailty, par = "par", true = c(trt = -0.50, fv = 0.75), estvarname = "b", se = "se", methodvar = "model", by = "fv_dist")
-  print(summary(x))
-  print(summary(x, ci_level = 0.99))
+  expect_output(print(summary(x)))
+  expect_output(print(summary(x, ci_level = 0.99)))
   x <- multisimsum(data = frailty, par = "par", true = c(trt = -0.50, fv = 0.75), estvarname = "b", se = "se", methodvar = "model")
-  print(summary(x))
+  expect_output(print(summary(x)))
   data("frailty")
   x <- multisimsum(data = frailty, par = "par", true = c(trt = -0.50, fv = 0.75), estvarname = "b", se = "se", by = "fv_dist")
-  print(summary(x))
+  expect_output(print(summary(x)))
   data("frailty")
   x <- multisimsum(data = frailty, par = "par", true = c(trt = -0.50, fv = 0.75), estvarname = "b", se = "se")
-  print(summary(x))
-  print(summary(x), sstat = c("bias", "bccover"))
+  expect_output(print(summary(x)))
+  expect_output(print(summary(x), sstat = c("bias", "bccover")))
 })
 
 test_that("summary.multisimsum returns an object of class summary.multisimsum", {
